pub enum SellerFreightClass {
Show 18 variants
_50,
_55,
_60,
_65,
_70,
_775,
_85,
_925,
_100,
_110,
_125,
_150,
_175,
_200,
_250,
_300,
_400,
_500,
}Expand description
SellerFreightClass : The freight class of the shipment. For information about determining the freight class, contact the carrier. The freight class of the shipment. For information about determining the freight class, contact the carrier.
Variants
_50
_55
_60
_65
_70
_775
_85
_925
_100
_110
_125
_150
_175
_200
_250
_300
_400
_500